==> ws-v3.70.7-src.tar.gz: ws-v3.70-7/include/btron/WSDbtronPrivateTimer.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDXPRIVATETIMER_H
#define WSDXPRIVATETIMER_H

#include <basic.h>
#include <WSDprivateTimer.h>
#include <WSClistData.h>

class WSDbtronPrivateTimer: public WSDprivateTimer {
  private:
static WSClistData _instance_list;
   long  _interval_id;
   static void _timer_process(W);
   void   _timer_set();    
  public:
   WSDbtronPrivateTimer();
   virtual ~WSDbtronPrivateTimer();

   virtual void startTimer();
   virtual void stopTimer();
   void _timer_callback(WSCulong);

static   WSCbool isValid(WSDbtronPrivateTimer*);

   WSMFclassDef(WSDbtronPrivateTimer,WSDtimer);
};

#endif

==> ws-v3.80.3-src.tar.gz: ws-v3.80-3/include/btron/WSDbtronPrivateTimer.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDBTRONPRIVATETIMER_H
#define WSDBTRONPRIVATETIMER_H

#include <basic.h>
#include <WSDprivateTimer.h>
#include <WSClistData.h>

class WSDbtronPrivateTimer: public WSDprivateTimer {
  private:
static WSClistData _instance_list;
   long  _interval_id;
   static void _timer_process(W);
   void   _timer_set();    
  public:
   WSDbtronPrivateTimer();
   virtual ~WSDbtronPrivateTimer();

   virtual void startTimer();
   virtual void stopTimer();
   void _timer_callback(WSCulong);

static   WSCbool isValid(WSDbtronPrivateTimer*);

   WSMFclassDef(WSDbtronPrivateTimer,WSDtimer);
};

#endif
